bayespy.inference.vmp.nodes.gaussian.GaussianGammaISODistribution.compute_logpdf
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISODistribution.compute_logpdf